Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(327)

Unified Diff: runtime/vm/parser.cc

Issue 14925005: Remove stack_frame_<arch>.cc files. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/locations.cc ('k') | runtime/vm/scopes.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/parser.cc
===================================================================
--- runtime/vm/parser.cc (revision 22469)
+++ runtime/vm/parser.cc (working copy)
@@ -159,22 +159,22 @@
// Compute start indices to parameters and locals, and the number of
// parameters to copy.
if (num_opt_params == 0) {
// Parameter i will be at fp[kLastParamSlotIndex + num_params - 1 - i] and
// local variable j will be at fp[kFirstLocalSlotIndex - j].
ASSERT(GetSavedArgumentsDescriptorVar() == NULL);
- first_parameter_index_ = kLastParamSlotIndex + num_params - 1;
- first_stack_local_index_ = kFirstLocalSlotIndex;
+ first_parameter_index_ = kParamEndSlotFromFp + num_params;
+ first_stack_local_index_ = kFirstLocalSlotFromFp;
num_copied_params_ = 0;
} else {
// Parameter i will be at fp[kFirstLocalSlotIndex - i] and local variable
// j will be at fp[kFirstLocalSlotIndex - num_params - j].
// The saved arguments descriptor variable must be allocated similarly to
// a parameter, so that it gets both a frame slot and a context slot when
// captured.
if (GetSavedArgumentsDescriptorVar() != NULL) {
num_params += 1;
}
- first_parameter_index_ = kFirstLocalSlotIndex;
+ first_parameter_index_ = kFirstLocalSlotFromFp;
first_stack_local_index_ = first_parameter_index_ - num_params;
num_copied_params_ = num_params;
}
@@ -159,22 +159,22 @@
// parameters to copy.
if (num_opt_params == 0) {
- // Parameter i will be at fp[kLastParamSlotIndex + num_params - 1 - i] and
- // local variable j will be at fp[kFirstLocalSlotIndex - j].
+ // Parameter i will be at fp[kParamEndSlotFromFp + num_params - i] and
+ // local variable j will be at fp[kFirstLocalSlotFromFp - j].
ASSERT(GetSavedArgumentsDescriptorVar() == NULL);
@@ -159,22 +159,22 @@
num_copied_params_ = 0;
} else {
- // Parameter i will be at fp[kFirstLocalSlotIndex - i] and local variable
- // j will be at fp[kFirstLocalSlotIndex - num_params - j].
+ // Parameter i will be at fp[kFirstLocalSlotFromFp - i] and local variable
+ // j will be at fp[kFirstLocalSlotFromFp - num_params - j].
// The saved arguments descriptor variable must be allocated similarly to
// a parameter, so that it gets both a frame slot and a context slot when
« no previous file with comments | « runtime/vm/locations.cc ('k') | runtime/vm/scopes.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698